package com.nationrel.modules.fta.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.io.Serializable;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;
import org.hibernate.validator.constraints.Length;

/**
 *
 * @TableName fta_analysis_setting
 */
@Schema(description = "分析计算配置表")
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
@Builder
@TableName(value ="fta_analysis_setting")
public class FtaAnalysisSetting {

    @TableId(type = IdType.AUTO)
    private Integer id;

    @TableField(exist = false)
    private String analysisId;

    /**
     * 全局时间校准参数
     */
    @Schema(description = "全局时间校准参数")
    @Length(max = 30, message = "checkData")
    private String paramTime;

    /**
     * 是否输出顶事件与中间事件失效概率F
     */
    @Schema(description = "是否输出顶事件与中间事件失效概率F")
    private String calculateF;

    /**
     * 是否输出顶事件与中间事件可靠度R
     */
    @Schema(description = "是否输出顶事件与中间事件可靠度R")
    private String calculateR;

    /**
     * 是否输出顶事件与中间事件失效率λ
     */
    @Schema(description = "是否输出顶事件与中间事件失效率λ")
    private String calculateLamda;

    /**
     * 是否输出顶事件与中间事件MTBF
     */
    @Schema(description = "是否输出顶事件与中间事件MTBF")
    private String calculateMtbf;

    /**
     * 是否输出最小割集失效概率F
     */
    @Schema(description = "是否输出最小割集失效概率F")
    private String calculateMinCutsetF;

    /**
     * 是否输出最小割集可靠度R
     */
    @Schema(description = "是否输出最小割集可靠度R")
    private String calculateMinCutsetR;

    /**
     * 是否输出最小割集失效率λ
     */
    @Schema(description = "是否输出最小割集失效率λ")
    private String calculateMinCutsetLamda;

    /**
     * 是否输出最小割集MTBF
     */
    @Schema(description = "是否输出最小割集MTBF")
    private String calculateMinCutsetMtbf;

    /**
     * 是否输出底事件失效概率F
     */
    @Schema(description = "是否输出底事件失效概率F")
    private String calculateCircleF;

    /**
     * 是否输出底事件可靠度R
     */
    @Schema(description = "是否输出底事件可靠度R")
    private String calculateCircleR;

    /**
     * 是否输出底事件割集重要度FV
     */
    @Schema(description = "是否输出底事件割集重要度FV")
    private String calculateCircleFv;

    /**
     * 是否输出底事件风险增加当量RAW
     */
    @Schema(description = "是否输出底事件风险增加当量RAW")
    private String calculateCircleRaw;

    /**
     * 是否输出底事件风险减少当量RRW
     */
    @Schema(description = "是否输出底事件风险减少当量RRW")
    private String calculateCircleRrw;

    /**
     * 是否输出底事件概率重要度mif
     */
    @Schema(description = "是否输出底事件概率重要度mif")
    private String calculateCircleMif;

    /**
     * 是否输出底事件结构重要度sif
     */
    @Schema(description = "是否输出底事件结构重要度sif")
    private String calculateCircleSif;

    /**
     * 是否输出底事件关键重要度cif
     */
    @Schema(description = "是否输出底事件关键重要度cif")
    private String calculateCircleCif;

    public static FtaAnalysisSetting getDefaultSetting() {
        return FtaAnalysisSetting.builder()
                .paramTime("10")
                .calculateF("1")
                .calculateR("0")
                .calculateLamda("0")
                .calculateMtbf("0")
                .calculateMinCutsetF("1")
                .calculateMinCutsetR("0")
                .calculateMinCutsetLamda("0")
                .calculateMinCutsetMtbf("0")
                .calculateCircleF("1")
                .calculateCircleR("0")
                .calculateCircleFv("1")
                .calculateCircleRaw("1")
                .calculateCircleRrw("1")
                .calculateCircleMif("1")
                .calculateCircleSif("1")
                .calculateCircleCif("1")
                .build();
    }

    /**
     * fta导入时，根据导入的数据更新setting
     * @param topEvent
     */
    public void updateByRdfmFaultNetModel(RdfmFaultNetModel topEvent) {
        paramTime = topEvent.getParamTime();
        calculateF = topEvent.getCalculateF();
        calculateR = topEvent.getCalculateR();
        calculateLamda = topEvent.getCalculateLamda();
        calculateMtbf = topEvent.getCalculateMtbf();
        calculateMinCutsetF = topEvent.getCalculateMinCutsetF();
        calculateMinCutsetR = topEvent.getCalculateMinCutsetR();
        calculateMinCutsetLamda = topEvent.getCalculateMinCutsetLamda();
        calculateMinCutsetMtbf = topEvent.getCalculateMinCutsetMtbf();
        calculateCircleF = topEvent.getCalculateCircleF();
        calculateCircleR = topEvent.getCalculateCircleR();
        calculateCircleFv = topEvent.getCalculateCircleFv();
        calculateCircleRaw = topEvent.getCalculateCircleRaw();
        calculateCircleRrw = topEvent.getCalculateCircleRrw();
        calculateCircleMif = topEvent.getCalculateCircleMif();
        calculateCircleSif = topEvent.getCalculateCircleSif();
        calculateCircleCif = topEvent.getCalculateCircleCif();
    }
}
